Inori - The Universal API Client Constructor
============================================

.. |pypi| image:: https://img.shields.io/pypi/v/inori.svg
    :target: https://pypi.org/project/inori
    :alt: PyPI

.. |pypi_version| image:: https://img.shields.io/pypi/pyversions/inori.svg
    :alt: PyPI - Python Version
    :target: https://github.com/jsfehler/inori

.. |license| image:: https://img.shields.io/github/license/jsfehler/inori.svg
    :alt: GitHub
    :target: https://github.com/jsfehler/inori/blob/master/LICENSE

.. |pyup| image:: https://pyup.io/repos/github/jsfehler/inori/shield.svg
    :alt: Updates
    :target: https://pyup.io/repos/github/jsfehler/inori

.. |CI| image:: https://github.com/jsfehler/inori/workflows/CI/badge.svg
    :target: https://github.com/jsfehler/inori/actions/workflows/run_tests.yml
    :alt: Build status

.. |coverage| image:: https://codecov.io/gh/jsfehler/inori/branch/master/graph/badge.svg?token=C1vfu8YgWn
    :target: https://codecov.io/gh/jsfehler/inori

|pypi| |pypi_version| |license| |pyup| |CI| |coverage|

Documentation
-------------

https://inori.readthedocs.io/en/latest/
